/* -*- tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
import lejos.nxt.*;
import java.util.ArrayList;
import lejos.nxt.comm.*;
import java.io.*;

/**
 * Bluetooth control behavior. It reads integers from a bluetooth
 * input stream, interpreting them as keycodes.
 * It reacts only on the keycodes connectred with the arrow keys (up,
 * down, left, right) and tells Marvin to drive accordingly.
 *
 * @author Bent Bisballe Nyeng, Kasper Sohn and Johnny Rieper
 * @version January 2009
 */
public class BTController extends Behavior 
{
  // KeyCodes:
  private static final int directionLeft = 37; // left
  private static final int directionRight = 39; // right
  private static final int directionForward = 38; // up
  private static final int directionBackward = 40; // down

  /**
   * BTController constructor.
   * @param behaviors List of lower priority behaviours.
   * @param ctrl The motor control parameters.
   */
  public BTController(ArrayList behaviors, Ctrl ctrl)
  {
    super(behaviors, ctrl);
  }
   
  public void run() 
  {
    NXTConnection conn = Bluetooth.waitForConnection();
    DataInputStream istream = conn.openDataInputStream();

    while(true) {
	    int direction = 0;
	    try {
        if(istream.available() > 0) direction = istream.readInt();
        else delay(200);
	    } catch(java.io.IOException e) {
        direction = 0;
	    }

	    if(direction >= directionLeft && direction <= directionBackward) {
        suppressLower();		    

        switch(direction) {
        case directionLeft:
          left(200);
          break;

        case directionRight:
          right(200);
          break;

        case directionForward:
          forward(200);
          break;

        case directionBackward:
          backward(200);
          break;
        }
        stop(1);

        unsuppressLower();

        try {
          // Empty input buffer... we only want to use the latest keystroke.
          while(istream.available() > 1) istream.readInt();
        } catch(java.io.IOException e) {
        }
	    }
    }
  }
}


