/* -*- tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */

/**
 * This class is used to handle the controls parameters of Marvin.
 * It is used for cross thread communication, and simply sets and gets a number of parameters
 * through synchronized methods.
 * The parameters are left and right motor power offsets, and gyroscope tilt angle offset.
 *
 * @author Bent Bisballe Nyeng, Kasper Sohn and Johnny Rieper
 * @version January 2009
 */
class Ctrl {
  private double offsetLeft = 0.0;
  private double offsetRight = 0.0;
  private double tiltAngle = 0.0;

  /**
   * Set left motor power offset.
   * @param offset A double containing the left motor power offset in degrees per second.
   */
  public synchronized void setLeftMotorOffset(double offset)
  {
    this.offsetLeft = offset;
  }

  /**
   * Set right motor power offset.
   * @param offset A double containing the right motor power offset in degrees per second.
   */
  public synchronized void setRightMotorOffset(double offset)
  {
    this.offsetRight = offset;
  }

  /**
   * Get left motor power offset.
   * @return A double containing the left motor power offset in degrees per second.
   */
  public synchronized double leftMotorOffset()
  {
    return this.offsetLeft;
  }

  /**
   * Get right motor power offset.
   * @return A double containing the right motor power offset in degrees per second.
   */
  public synchronized double rightMotorOffset()
  {
    return this.offsetRight;
  }

  /**
   * Set the tilt angle offset.
   * The value seems to work incrementally, hence the accumulative nature of the set method.
   * @param angle A double containing the tilt angle offset in degrees.
   */
  public synchronized void setTiltAngle(double angle)
  {
    this.tiltAngle += angle;
  }

  /**
   * Get the tilt angle offset.
   * @return A double containing the tilt angle offset in degrees.
   */
  public synchronized double tiltAngle()
  {
    return this.tiltAngle;
  }

}