/* -*- tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
import lejos.pc.comm.*;
import java.io.*;
import javax.swing.*;
import java.awt.*; 
import java.awt.event.*;

/**
 * This class is the main class of the Bluetooth Control program, PC-side.
 * It creates an empty window, and catches keyborad input, which are sent
 * to Marvin through a bluetooth output stream.
 * All keycodes are sent... not just the arrow keys.
 *
 * NOTE: Marvin must be running, and listeing for incoming bluetooth
 * connections when this program is run, otherwise it will fail.
 *
 * @author Bent Bisballe Nyeng, Kasper Sohn and Johnny Rieper
 * @version January 2009
 */
class PCController {
  public static void main(String [] args)
  {
    // Initiate bluetooth communication.
    System.out.println("Connecting to Marvin...");
    NXTComm nxtComm = null;
    try {
	    nxtComm = NXTCommFactory.createNXTComm(NXTCommFactory.BLUETOOTH);
	    NXTInfo nxtInfo = new NXTInfo("Marvin", "00:16:53:06:E3:36");
	    nxtComm.open(nxtInfo);
    } catch( lejos.pc.comm.NXTCommException e ) {
	    System.out.println("NXTCommException" + e.getMessage());
	    return;
    }
    System.out.println("Connected.");

    // Attach output stream to the bluetooth connection
    OutputStream os = nxtComm.getOutputStream();
    final DataOutputStream dos = new DataOutputStream(os);

    // Create window
    JFrame frame = new JFrame("Marvin Control");
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.setSize(new Dimension(100, 100));
    frame.setVisible(true); 

    // Create keyboard listener
    frame.addKeyListener(new KeyListener() {
        public void keyPressed(KeyEvent e) {
          try {
            dos.writeInt(e.getKeyCode());
            dos.flush();
          } catch( java.io.IOException e2 ) {
            System.out.println("IOException");
            return;
          }
        }
        public void keyReleased(KeyEvent e) {}
        public void keyTyped(KeyEvent e) {}

	    });
  }
}